@@ -14,6 +14,7 @@ import (
 	"time"
 
 	"github.com/blang/semver"
+	"github.com/logrusorgru/aurora"
 	"github.com/spf13/cobra"
 
 	"github.com/superfly/flyctl/api"
@@ -429,6 +430,16 @@ func promptToUpdate(ctx context.Context) (context.Context, error) {
 	return ctx, nil
 }
 
+func PromptToMigrate(ctx context.Context, app *api.AppCompact) {
+	if app.PlatformVersion == "nomad" {
+		config := appconfig.ConfigFromContext(ctx)
+		if config != nil {
+			io := iostreams.FromContext(ctx)
+			fmt.Fprintf(io.ErrOut, "%s Apps v1 Platform is deprecated. We recommend migrating your app with:\nfly migrate-to-v2 -c %s", aurora.Yellow("WARN"), config.ConfigFilePath())
+		}
+	}
+}
+
 func killOldAgent(ctx context.Context) (context.Context, error) {
 	path := filepath.Join(state.ConfigDirectory(ctx), "agent.pid")
 
@@ -564,7 +575,7 @@ func appConfigFilePaths(ctx context.Context) (paths []string) {
 	return
 }
 
-var errRequireAppName = fmt.Errorf("the config for your app is missing an app name, add an app_name field to the fly.toml file or specify with the -a flag`")
+var errRequireAppName = fmt.Errorf("the config for your app is missing an app name, add an app field to the fly.toml file or specify with the -a flag`")
 
 // RequireAppName is a Preparer which makes sure the user has selected an
 // application name via command line arguments, the environment or an application
