@@ -133,7 +133,7 @@ func (md *machineDeployment) deployMachinesApp(ctx context.Context) error {
 	groupsWithAutostopEnabled := make(map[string]bool)
 	total := len(processGroupMachineDiff.groupsNeedingMachines)
 	for idx, name := range maps.Keys(processGroupMachineDiff.groupsNeedingMachines) {
-		fmt.Fprintf(md.io.Out, "No machines in group %s, launching one new machine\n", md.colorize.Bold(name))
+		fmt.Fprintf(md.io.Out, "No machines in group %s, launching a new machine\n", md.colorize.Bold(name))
 		leasableMachine, err := md.spawnMachineInGroup(ctx, name, idx, total, nil)
 		if err != nil {
 			return err
@@ -413,7 +413,11 @@ func (md *machineDeployment) warnAboutProcessGroupChanges(ctx context.Context, d
 		return
 	}
 
-	fmt.Fprintln(md.io.Out, "Process groups have changed. This will:")
+	if md.isFirstDeploy {
+		fmt.Fprintln(md.io.Out, "This deployment will:")
+	} else {
+		fmt.Fprintln(md.io.Out, "Process groups have changed. This will:")
+	}
 
 	if willRemoveMachines {
 		bullet := md.colorize.Red("*")
@@ -425,7 +429,19 @@ func (md *machineDeployment) warnAboutProcessGroupChanges(ctx context.Context, d
 	if willAddMachines {
 		bullet := md.colorize.Green("*")
 		for name := range diff.groupsNeedingMachines {
-			fmt.Fprintf(md.io.Out, " %s create 1 \"%s\" machine\n", bullet, name)
+			var description string
+			groupConfig, err := md.appConfig.Flatten(name)
+			switch {
+			case err != nil:
+				continue
+			case !md.increasedAvailability || len(groupConfig.Mounts) > 0:
+				description = fmt.Sprintf("1 \"%s\" machine", name)
+			case len(groupConfig.AllServices()) > 0:
+				description = fmt.Sprintf("2 \"%s\" machines", name)
+			default:
+				description = fmt.Sprintf("1 \"%s\" machine and 1 standby machine for it", name)
+			}
+			fmt.Fprintf(md.io.Out, " %s create %s\n", bullet, description)
 		}
 	}
 	fmt.Fprint(md.io.Out, "\n")
