@@ -15,7 +15,7 @@ func New() *cobra.Command {
 organization the current user belongs to.
 `
 		short = "Move an app to another organization"
-		usage = "move [APPNAME]"
+		usage = "move <APPNAME>"
 	)
 
 	move := command.New(usage, short, long, apps.RunMove,
